smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver

# ``smartcard`.`wx`.`CardAndReaderTreePanel`.`CardAndReaderTreePanel`.`_ReaderObserver``

class documentation

`class _ReaderObserver(ReaderObserver):`

View In Hierarchy

Inner ReaderObserver. Gets notified of reader insertion/removal by the ReaderMonitor.

Method | `__init__` | Undocumented
Method | `update` | ReaderObserver callback that is notified when readers are added or removed.
Instance Variable | `readertreectrl` | Undocumented

def __init__(self, readertreectrl):
overrides `smartcard.ReaderMonitoring.ReaderObserver.__init__`

Undocumented

def update(self, observable, handlers):
overrides `smartcard.ReaderMonitoring.ReaderObserver.update`

ReaderObserver callback that is notified when readers are added or removed.

readertreectrl =

Undocumented